==> com.liferay.commerce.term.service-1.0.2-sources-commercial.jar: com/liferay/commerce/term/internal/entry/type/PaymentTermsCommerceTermEntryType.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.commerce.term.internal.entry.type;

import com.liferay.commerce.term.constants.CommerceTermEntryConstants;
import com.liferay.commerce.term.entry.type.CommerceTermEntryType;
import com.liferay.portal.kernel.language.LanguageUtil;
import com.liferay.portal.kernel.util.ResourceBundleUtil;

import java.util.Locale;
import java.util.ResourceBundle;

import org.osgi.service.component.annotations.Component;

/**
 * @author Alessio Antonio Rendina
 */
@Component(
	enabled = false, immediate = true,
	property = "commerce.term.entry.type.key=" + CommerceTermEntryConstants.TYPE_PAYMENT_TERMS,
	service = CommerceTermEntryType.class
)
public class PaymentTermsCommerceTermEntryType
	implements CommerceTermEntryType {

	@Override
	public String getKey() {
		return CommerceTermEntryConstants.TYPE_PAYMENT_TERMS;
	}

	@Override
	public String getLabel(Locale locale) {
		ResourceBundle resourceBundle = ResourceBundleUtil.getBundle(
			"content.Language", locale, getClass());

		return LanguageUtil.get(
			resourceBundle, CommerceTermEntryConstants.TYPE_PAYMENT_TERMS);
	}

}

==> com.liferay.commerce.term.service-1.0.23-sources-commercial.jar: com/liferay/commerce/term/internal/entry/type/PaymentTermsCommerceTermEntryType.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.commerce.term.internal.entry.type;

import com.liferay.commerce.term.constants.CommerceTermEntryConstants;
import com.liferay.commerce.term.entry.type.CommerceTermEntryType;
import com.liferay.portal.kernel.language.Language;
import com.liferay.portal.kernel.util.ResourceBundleUtil;

import java.util.Locale;
import java.util.ResourceBundle;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Alessio Antonio Rendina
 */
@Component(
	enabled = false, immediate = true,
	property = "commerce.term.entry.type.key=" + CommerceTermEntryConstants.TYPE_PAYMENT_TERMS,
	service = CommerceTermEntryType.class
)
public class PaymentTermsCommerceTermEntryType
	implements CommerceTermEntryType {

	@Override
	public String getKey() {
		return CommerceTermEntryConstants.TYPE_PAYMENT_TERMS;
	}

	@Override
	public String getLabel(Locale locale) {
		ResourceBundle resourceBundle = ResourceBundleUtil.getBundle(
			"content.Language", locale, getClass());

		return _language.get(
			resourceBundle, CommerceTermEntryConstants.TYPE_PAYMENT_TERMS);
	}

	@Reference
	private Language _language;

}
